@@ -11,10 +11,9 @@ areaHelper1 <- function(x, plts, db, grpBy, byPlot){
   grpT <- names(db$TREE)[names(db$TREE) %in% grpBy & names(db$TREE) %in% c(grpP, grpC) == FALSE]
 
   ### Only joining tables necessary to produce plot level estimates, adjusted for non-response
-  data <- select(db$PLOT, c('PLT_CN', 'STATECD', 'MACRO_BREAKPOINT_DIA', 'INVYR', 'MEASYEAR', 'PLOT_STATUS_CD', grpP, 'aD_p', 'sp')) %>%
-    left_join(select(db$COND, c('PLT_CN', 'CONDPROP_UNADJ', 'PROP_BASIS', 'COND_STATUS_CD', 'CONDID', grpC, 'aD_c', 'landD')), by = c('PLT_CN')) %>%
-    left_join(select(db$TREE, c('PLT_CN', 'CONDID', grpT)), by = c('PLT_CN', 'CONDID')) #%>%
-  #filter(DIA >= 5)
+  data <- db$PLOT %>%
+    left_join(db$COND, by = c('PLT_CN')) %>%
+    left_join(db$TREE, by = c('PLT_CN', 'CONDID'))
 
   ## Comprehensive indicator function
   data$aDI <- data$landD * data$aD_p * data$aD_c * data$sp
@@ -93,6 +92,7 @@ areaHelper2 <- function(x, popState, t, grpBy, method){
     group_by(ESTN_UNIT_CN, .dots = grpBy) %>%
     summarize(aEst = unitMean(ESTN_METHOD, a, nh,  w, aStrat),
               aVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, av, aStrat, aEst),
+              N = first(p2eu),
               plotIn_AREA = sum(plotIn_AREA, na.rm = TRUE))
 
   out <- list(tEst = tEst)
