@@ -1,6 +1,6 @@
-#' @export
-biomass <- function(db,
-                       grpBy = NULL,
+bioStarter <- function(x,
+                       db,
+                       grpBy_quo = NULL,
                        polys = NULL,
                        returnSpatial = FALSE,
                        bySpecies = FALSE,
@@ -13,13 +13,42 @@ biomass <- function(db,
                        areaDomain = NULL,
                        totals = FALSE,
                        byPlot = FALSE,
-                       nCores = 1) {
+                       nCores = 1,
+                       remote,
+                       mr){
+
+  reqTables <- c('PLOT', 'TREE', 'COND', 'POP_PLOT_STRATUM_ASSGN', 'POP_ESTN_UNIT', 'POP_EVAL',
+                 'POP_STRATUM', 'POP_EVAL_TYP', 'POP_EVAL_GRP')
+  if (remote){
+    ## Store the original parameters here
+    params <- db
+
+    ## Read in one state at a time
+    db <- readFIA(dir = db$dir, common = db$common,
+                  tables = reqTables, states = x, ## x is the vector of state names
+                  nCores = nCores)
+
+    ## If a clip was specified, run it now
+    if ('mostRecent' %in% names(params)){
+      db <- clipFIA(db, mostRecent = params$mostRecent,
+                    mask = params$mask, matchEval = params$matchEval,
+                    evalid = params$evalid, designCD = params$designCD,
+                    nCores = nCores)
+    }
+
+  }else {
+    ## Really only want the required tables
+    db <- db[names(db) %in% reqTables]
+  }
+
+
+
   ## Need a plotCN, and a new ID
   db$PLOT <- db$PLOT %>% mutate(PLT_CN = CN,
                                 pltID = paste(UNITCD, STATECD, COUNTYCD, PLOT, sep = '_'))
 
   ##  don't have to change original code
-  grpBy_quo <- enquo(grpBy)
+  #grpBy_quo <- enquo(grpBy)
 
   # Probably cheating, but it works
   if (quo_name(grpBy_quo) != 'NULL'){
@@ -44,14 +73,13 @@ biomass <- function(db,
       # Convert to character
       grpBy <- names(d_quo)
     }
+  } else {
+    grpBy <- NULL
   }
 
   reqTables <- c('PLOT', 'TREE', 'COND', 'POP_PLOT_STRATUM_ASSGN', 'POP_ESTN_UNIT', 'POP_EVAL',
                  'POP_STRATUM', 'POP_EVAL_TYP', 'POP_EVAL_GRP')
-  ## Some warnings
-  if (class(db) != "FIA.Database"){
-    stop('db must be of class "FIA.Database". Use readFIA() to load your FIA data.')
-  }
+
   if (!is.null(polys) & first(class(polys)) %in% c('sf', 'SpatialPolygons', 'SpatialPolygonsDataFrame') == FALSE){
     stop('polys must be spatial polygons object of class sp or sf. ')
   }
@@ -66,7 +94,6 @@ biomass <- function(db,
     warning(paste('Method', method, 'unknown. Defaulting to Temporally Indifferent (TI).'))
   }
 
-
   # I like a unique ID for a plot through time
   if (byPlot) {grpBy <- c('pltID', grpBy)}
   # Save original grpBy for pretty return with spatial objects
@@ -91,19 +118,17 @@ biomass <- function(db,
     db$POP_EVAL <- bind_rows(filter(db$POP_EVAL, !(STATECD %in% 48)), txIDS)
   }
 
-
-
   ### AREAL SUMMARY PREP
   if(!is.null(polys)) {
-    # Convert polygons to an sf object
-    polys <- polys %>%
-      as('sf')%>%
-      mutate_if(is.factor,
-                as.character)
-    ## A unique ID
-    polys$polyID <- 1:nrow(polys)
-
-    # Add shapefile names to grpBy
+    # # Convert polygons to an sf object
+    # polys <- polys %>%
+    #   as('sf')%>%
+    #   mutate_if(is.factor,
+    #             as.character)
+    # ## A unique ID
+    # polys$polyID <- 1:nrow(polys)
+    #
+    # # Add shapefile names to grpBy
     grpBy = c(grpBy, 'polyID')
 
     ## Make plot data spatial, projected same as polygon layer
@@ -113,10 +138,8 @@ biomass <- function(db,
     coordinates(pltSF) <- ~LON+LAT
     proj4string(pltSF) <- '+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs'
     pltSF <- as(pltSF, 'sf') %>%
-      #st_transform(crs = st_crs(polys)$proj4string)
       st_transform(crs = st_crs(polys))
 
-
     ## Split up polys
     polyList <- split(polys, as.factor(polys$polyID))
     suppressWarnings({suppressMessages({
@@ -127,7 +150,6 @@ biomass <- function(db,
           library(dplyr)
           library(stringr)
           library(rFIA)
-          #library(sf)
         })
         out <- parLapply(cl, X = names(polyList), fun = areal_par, pltSF, polyList)
         #stopCluster(cl) # Keep the cluster active for the next run
@@ -143,7 +165,7 @@ biomass <- function(db,
     }
     ## Add polygon names to PLOT
     db$PLOT <- db$PLOT %>%
-      left_join(pltSF, by = 'pltID')
+      left_join(select(pltSF, polyID, pltID), by = 'pltID')
 
     # Test if any polygons cross state boundaries w/ different recent inventory years (continued w/in loop)
     if ('mostRecent' %in% names(db) & length(unique(db$POP_EVAL$STATECD)) > 1){
@@ -187,8 +209,8 @@ biomass <- function(db,
 
   # User defined domain indicator for area (ex. specific forest type)
   pcEval <- left_join(db$PLOT, select(db$COND, -c('STATECD', 'UNITCD', 'COUNTYCD', 'INVYR', 'PLOT')), by = 'PLT_CN')
-  areaDomain <- substitute(areaDomain)
-  pcEval$aD <- eval(areaDomain, pcEval) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
+  #areaDomain <- substitute(areaDomain)
+  pcEval$aD <- rlang::eval_tidy(areaDomain, pcEval) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
   if(!is.null(pcEval$aD)) pcEval$aD[is.na(pcEval$aD)] <- 0 # Make NAs 0s. Causes bugs otherwise
   if(is.null(pcEval$aD)) pcEval$aD <- 1 # IF NULL IS GIVEN, THEN ALL VALUES TRUE
   pcEval$aD <- as.numeric(pcEval$aD)
@@ -201,8 +223,8 @@ biomass <- function(db,
   rm(pcEval)
 
   # Same as above for tree (ex. trees > 20 ft tall)
-  treeDomain <- substitute(treeDomain)
-  tD <- eval(treeDomain, db$TREE) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
+  #treeDomain <- substitute(treeDomain)
+  tD <- rlang::eval_tidy(treeDomain, db$TREE) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
   if(!is.null(tD)) tD[is.na(tD)] <- 0 # Make NAs 0s. Causes bugs otherwise
   if(is.null(tD)) tD <- 1 # IF NULL IS GIVEN, THEN ALL VALUES TRUE
   db$TREE$tD <- as.numeric(tD)
@@ -213,20 +235,28 @@ biomass <- function(db,
     inner_join(select(db$POP_EVAL_TYP, c('EVAL_CN', 'EVAL_TYP')), by = c('CN' = 'EVAL_CN')) %>%
     filter(EVAL_TYP == 'EXPVOL' | EVAL_TYP == 'EXPCURR') %>%
     filter(!is.na(END_INVYR) & !is.na(EVALID) & END_INVYR >= 2003) %>%
-    distinct(END_INVYR, EVALID, .keep_all = TRUE)# %>%
-  #group_by(END_INVYR) %>%
-  #summarise(id = list(EVALID)
+    distinct(END_INVYR, EVALID, .keep_all = TRUE)
+
+  ## If a most-recent subset, make sure that we don't get two reporting years in
+  ## western states
+  if (mr) {
+    db$POP_EVAL <- db$POP_EVAL %>%
+      group_by(EVAL_TYP) %>%
+      filter(END_INVYR == max(END_INVYR, na.rm = TRUE))
+  }
+
 
   ## Make an annual panel ID, associated with an INVYR
 
   ### The population tables
-  pops <- select(db$POP_EVAL, c('EVALID', 'ESTN_METHOD', 'CN', 'END_INVYR')) %>%
+  pops <- select(db$POP_EVAL, c('EVALID', 'ESTN_METHOD', 'CN', 'END_INVYR', 'EVAL_TYP')) %>%
     rename(EVAL_CN = CN) %>%
     left_join(select(db$POP_ESTN_UNIT, c('CN', 'EVAL_CN', 'AREA_USED', 'P1PNTCNT_EU')), by = c('EVAL_CN')) %>%
     rename(ESTN_UNIT_CN = CN) %>%
     left_join(select(db$POP_STRATUM, c('ESTN_UNIT_CN', 'EXPNS', 'P2POINTCNT', 'CN', 'P1POINTCNT', 'ADJ_FACTOR_SUBP', 'ADJ_FACTOR_MICR', "ADJ_FACTOR_MACR")), by = c('ESTN_UNIT_CN')) %>%
     rename(STRATUM_CN = CN) %>%
     left_join(select(db$POP_PLOT_STRATUM_ASSGN, c('STRATUM_CN', 'PLT_CN', 'INVYR', 'STATECD')), by = 'STRATUM_CN') %>%
+    ungroup() %>%
     mutate_if(is.factor,
               as.character)
 
@@ -315,8 +345,24 @@ biomass <- function(db,
   ## Only the necessary plots for EVAL of interest
   db$PLOT <- filter(db$PLOT, PLT_CN %in% pops$PLT_CN)
 
+  ## Narrow up the tables to the necessary variables, reduces memory load
+  ## sent out the cores
+  ## Which grpByNames are in which table? Helps us subset below
+  grpP <- names(db$PLOT)[names(db$PLOT) %in% grpBy]
+  grpC <- names(db$COND)[names(db$COND) %in% grpBy & names(db$COND) %in% grpP == FALSE]
+  grpT <- names(db$TREE)[names(db$TREE) %in% grpBy & names(db$TREE) %in% c(grpP, grpC) == FALSE]
+
+
+  ### Only joining tables necessary to produce plot level estimates
+  db$PLOT <- select(ungroup(db$PLOT), PLT_CN, STATECD, COUNTYCD, MACRO_BREAKPOINT_DIA, INVYR, MEASYEAR, PLOT_STATUS_CD, all_of(grpP), aD_p, sp)
+  db$COND <- select(db$COND, 'PLT_CN', 'CONDPROP_UNADJ', 'PROP_BASIS', 'COND_STATUS_CD', 'CONDID', all_of(grpC), 'aD_c', 'landD')
+  db$TREE <- select(db$TREE, 'PLT_CN', 'CONDID', 'DIA', 'SPCD', 'TPA_UNADJ', 'SUBP', 'TREE', all_of(grpT), 'tD', 'typeD',
+                                'VOLCFNET', 'VOLCSNET', 'DRYBIO_AG', 'DRYBIO_BG', 'CARBON_AG', 'CARBON_BG')
+
+
   ## Merging state and county codes
   plts <- split(db$PLOT, as.factor(paste(db$PLOT$COUNTYCD, db$PLOT$STATECD, sep = '_')))
+  #plts <- split(db$PLOT, as.factor(db$PLOT$STATECD))
 
   suppressWarnings({
     ## Compute estimates in parallel -- Clusters in windows, forking otherwise
@@ -335,6 +381,7 @@ biomass <- function(db,
   })
 
   if (byPlot){
+
     ## back to dataframes
     out <- unlist(out, recursive = FALSE)
     tOut <- bind_rows(out[names(out) == 't'])
@@ -347,6 +394,8 @@ biomass <- function(db,
       grpBy <- grpBy[grpBy %in% c('LAT', 'LON') == FALSE]
 
     }
+
+    out <- list(tEst = tOut, grpBy = grpBy, aGrpBy = aGrpBy, grpByOrig = grpByOrig)
     ## Population estimation
   } else {
     ## back to dataframes
@@ -360,9 +409,19 @@ biomass <- function(db,
     aGrpBy <- c('YEAR', aGrpBy)
 
 
-    ## Splitting up by ESTN_UNIT
-    popState <- split(pops, as.factor(pops$STATECD))
+    ## Splitting up by STATECD and groups of 25 ESTN_UNIT_CNs
+    #estunit <- distinct(pops, ESTN_UNIT_CN) #%>%
+    #mutate(estID)
 
+    #estID <- seq(1, nrow(estunit), 50)
+    #estunit$estID <- rep_len(estID, length.out = nrow(estunit))
+    #pops <- pops %>%
+    #  left_join(estunit, by = 'ESTN_UNIT_CN') #%>%
+    #mutate(estBreaks = )
+
+    #popState <- split(pops, as.factor(pops$estID))
+    popState <- split(pops, as.factor(pops$STATECD))
+    #
     suppressWarnings({
       ## Compute estimates in parallel -- Clusters in windows, forking otherwise
       if (Sys.info()['sysname'] == 'Windows'){
@@ -434,7 +493,7 @@ biomass <- function(db,
           neu <- wgts %>%
             mutate(l = lambda) %>%
             group_by(ESTN_UNIT_CN) %>%
-            summarize(l = first(lambda),
+            summarize(l = 1 - first(lambda),
                       sumwgt = sum(l*(1-l)^(1-rank), na.rm = TRUE))
 
           ## Rejoining and computing wgts
@@ -455,7 +514,7 @@ biomass <- function(db,
           ## Want sum of weighitng functions
           neu <- wgts %>%
             group_by(lambda, ESTN_UNIT_CN) %>%
-            summarize(l = first(lambda),
+            summarize(l = 1 - first(lambda),
                       sumwgt = sum(l*(1-l)^(1-rank), na.rm = TRUE))
 
           ## Rejoining and computing wgts
@@ -488,6 +547,139 @@ biomass <- function(db,
 
     }
 
+
+    out <- list(tEst = tEst, aEst = aEst, grpBy = grpBy, aGrpBy = aGrpBy, grpByOrig = grpByOrig)
+  }
+
+  return(out)
+
+}
+
+
+
+
+
+
+#' @export
+biomass <- function(db,
+                       grpBy = NULL,
+                       polys = NULL,
+                       returnSpatial = FALSE,
+                       bySpecies = FALSE,
+                       bySizeClass = FALSE,
+                       landType = 'forest',
+                       treeType = 'live',
+                       method = 'TI',
+                       lambda = .5,
+                       treeDomain = NULL,
+                       areaDomain = NULL,
+                       totals = FALSE,
+                       variance = FALSE,
+                       byPlot = FALSE,
+                       nCores = 1) {
+
+  ##  don't have to change original code
+  grpBy_quo <- rlang::enquo(grpBy)
+  areaDomain <- rlang::enquo(areaDomain)
+  treeDomain <- rlang::enquo(treeDomain)
+
+  ### Is DB remote?
+  remote <- ifelse(class(db) == 'Remote.FIA.Database', 1, 0)
+  if (remote){
+
+    iter <- db$states
+
+    ## In memory
+  } else {
+    ## Some warnings
+    if (class(db) != "FIA.Database"){
+      stop('db must be of class "FIA.Database". Use readFIA() to load your FIA data.')
+    }
+
+    ## an iterator for remote
+    iter <- 1
+
+  }
+
+  ## Check for a most recent subset
+  if (remote){
+    if ('mostRecent' %in% names(db)){
+      mr = db$mostRecent # logical
+    } else {
+      mr = FALSE
+    }
+    ## In-memory
+  } else {
+    if ('mostRecent' %in% names(db)){
+      mr = TRUE
+    } else {
+      mr = FALSE
+    }
+  }
+
+  ### AREAL SUMMARY PREP
+  if(!is.null(polys)) {
+    # Convert polygons to an sf object
+    polys <- polys %>%
+      as('sf')%>%
+      mutate_if(is.factor,
+                as.character)
+    ## A unique ID
+    polys$polyID <- 1:nrow(polys)
+  }
+
+
+
+  ## Run the main portion
+  out <- lapply(X = iter, FUN = bioStarter, db,
+                grpBy_quo = grpBy_quo, polys, returnSpatial,
+                bySpecies, bySizeClass,
+                landType, treeType, method,
+                lambda, treeDomain, areaDomain,
+                totals, byPlot, nCores, remote, mr)
+  ## Bring the results back
+  out <- unlist(out, recursive = FALSE)
+  aEst <- bind_rows(out[names(out) == 'aEst'])
+  tEst <- bind_rows(out[names(out) == 'tEst'])
+  grpBy <- out[names(out) == 'grpBy'][[1]]
+  aGrpBy <- out[names(out) == 'aGrpBy'][[1]]
+  grpByOrig <- out[names(out) == 'grpByOrig'][[1]]
+
+
+  if (byPlot){
+    ## back to dataframes
+    tOut <- tEst
+
+  } else {
+
+    suppressMessages({suppressWarnings({
+      ## If a clip was specified, handle the reporting years
+      if (mr){
+        ## If a most recent subset, ignore differences in reporting years across states
+        ## instead combine most recent information from each state
+        # ID mr years by group
+        maxyearsT <- tEst %>%
+          select(grpBy) %>%
+          group_by(.dots = grpBy[!c(grpBy %in% 'YEAR')]) %>%
+          summarise(YEAR = max(YEAR, na.rm = TRUE))
+        maxyearsA <- aEst %>%
+          select(aGrpBy) %>%
+          group_by(.dots = aGrpBy[!c(aGrpBy %in% 'YEAR')]) %>%
+          summarise(YEAR = max(YEAR, na.rm = TRUE))
+
+        # Combine estimates
+        aEst <- aEst %>%
+          ungroup() %>%
+          select(-c(YEAR)) %>%
+          left_join(maxyearsA, by = aGrpBy[!c(aGrpBy %in% 'YEAR')])
+        tEst <- tEst %>%
+          ungroup() %>%
+          select(-c(YEAR)) %>%
+          left_join(maxyearsT, by = grpBy[!c(grpBy %in% 'YEAR')])
+
+      }
+    })})
+
     ##---------------------  TOTALS and RATIOS
     # Area
     # aTotal <- aEst %>%
@@ -560,6 +752,26 @@ biomass <- function(db,
                CARB_AG_TOTAL_SE = sqrt(cagVar) / CARB_AG_TOTAL *100,
                CARB_BG_TOTAL_SE = sqrt(cbgVar) / CARB_BG_TOTAL *100,
                CARB_TOTAL_SE = sqrt(ctVar) / CARB_TOTAL *100,
+
+               ## VAR RATIO
+               NETVOL_ACRE_VAR = nvaVar,
+               SAWVOL_ACRE_VAR = svaVar,
+               BIO_AG_ACRE_VAR = baaVar,
+               BIO_BG_ACRE_VAR = bbaVar,
+               BIO_ACRE_VAR = btaVar,
+               CARB_AG_ACRE_VAR = caaVar,
+               CARB_BG_ACRE_VAR = cbaVar,
+               CARB_ACRE_VAR = ctaVar,
+               ## VAR TOTAL
+               AREA_TOTAL_VAR = aVar,
+               NETVOL_TOTAL_VAR = nvVar,
+               SAWVOL_TOTAL_VAR = svVar,
+               BIO_AG_TOTAL_VAR = bagVar,
+               BIO_BG_TOTAL_VAR = bbgVar,
+               BIO_TOTAL_VAR = btVar,
+               CARB_AG_TOTAL_VAR = cagVar,
+               CARB_BG_TOTAL_VAR = cbgVar,
+               CARB_TOTAL_VAR = ctVar,
                ## nPlots
                nPlots_TREE = plotIn_TREE,
                nPlots_AREA = plotIn_AREA)
@@ -568,24 +780,50 @@ biomass <- function(db,
 
     if (totals) {
 
-      tOut <- tOut %>%
-        select(grpBy, "NETVOL_ACRE","SAWVOL_ACRE","BIO_AG_ACRE","BIO_BG_ACRE",
-               "BIO_ACRE","CARB_AG_ACRE","CARB_BG_ACRE","CARB_ACRE","NETVOL_TOTAL",
-               "SAWVOL_TOTAL","BIO_AG_TOTAL","BIO_BG_TOTAL","BIO_TOTAL","CARB_AG_TOTAL",
-               "CARB_BG_TOTAL","CARB_TOTAL", "AREA_TOTAL","NETVOL_ACRE_SE",
-               "SAWVOL_ACRE_SE","BIO_AG_ACRE_SE", "BIO_BG_ACRE_SE", "BIO_ACRE_SE",
-               "CARB_AG_ACRE_SE","CARB_BG_ACRE_SE","CARB_ACRE_SE","NETVOL_TOTAL_SE",
-               "SAWVOL_TOTAL_SE",  "BIO_AG_TOTAL_SE",  "BIO_BG_TOTAL_SE",
-               "BIO_TOTAL_SE", "CARB_AG_TOTAL_SE", "CARB_BG_TOTAL_SE", "CARB_TOTAL_SE",
-               "AREA_TOTAL_SE","nPlots_TREE","nPlots_AREA")
+      if (variance){
+        tOut <- tOut %>%
+          select(grpBy, "NETVOL_ACRE","SAWVOL_ACRE","BIO_AG_ACRE","BIO_BG_ACRE",
+                 "BIO_ACRE","CARB_AG_ACRE","CARB_BG_ACRE","CARB_ACRE","NETVOL_TOTAL",
+                 "SAWVOL_TOTAL","BIO_AG_TOTAL","BIO_BG_TOTAL","BIO_TOTAL","CARB_AG_TOTAL",
+                 "CARB_BG_TOTAL","CARB_TOTAL", "AREA_TOTAL","NETVOL_ACRE_VAR",
+                 "SAWVOL_ACRE_VAR","BIO_AG_ACRE_VAR", "BIO_BG_ACRE_VAR", "BIO_ACRE_VAR",
+                 "CARB_AG_ACRE_VAR","CARB_BG_ACRE_VAR","CARB_ACRE_VAR","NETVOL_TOTAL_VAR",
+                 "SAWVOL_TOTAL_VAR",  "BIO_AG_TOTAL_VAR",  "BIO_BG_TOTAL_VAR",
+                 "BIO_TOTAL_VAR", "CARB_AG_TOTAL_VAR", "CARB_BG_TOTAL_VAR", "CARB_TOTAL_VAR",
+                 "AREA_TOTAL_VAR","nPlots_TREE","nPlots_AREA", 'N')
+
+      } else {
+        tOut <- tOut %>%
+          select(grpBy, "NETVOL_ACRE","SAWVOL_ACRE","BIO_AG_ACRE","BIO_BG_ACRE",
+                 "BIO_ACRE","CARB_AG_ACRE","CARB_BG_ACRE","CARB_ACRE","NETVOL_TOTAL",
+                 "SAWVOL_TOTAL","BIO_AG_TOTAL","BIO_BG_TOTAL","BIO_TOTAL","CARB_AG_TOTAL",
+                 "CARB_BG_TOTAL","CARB_TOTAL", "AREA_TOTAL","NETVOL_ACRE_SE",
+                 "SAWVOL_ACRE_SE","BIO_AG_ACRE_SE", "BIO_BG_ACRE_SE", "BIO_ACRE_SE",
+                 "CARB_AG_ACRE_SE","CARB_BG_ACRE_SE","CARB_ACRE_SE","NETVOL_TOTAL_SE",
+                 "SAWVOL_TOTAL_SE",  "BIO_AG_TOTAL_SE",  "BIO_BG_TOTAL_SE",
+                 "BIO_TOTAL_SE", "CARB_AG_TOTAL_SE", "CARB_BG_TOTAL_SE", "CARB_TOTAL_SE",
+                 "AREA_TOTAL_SE","nPlots_TREE","nPlots_AREA")
+      }
+
+
 
     } else {
-      tOut <- tOut %>%
-        select(grpBy, "NETVOL_ACRE","SAWVOL_ACRE","BIO_AG_ACRE","BIO_BG_ACRE",
-               "BIO_ACRE","CARB_AG_ACRE","CARB_BG_ACRE","CARB_ACRE","NETVOL_ACRE_SE",
-               "SAWVOL_ACRE_SE","BIO_AG_ACRE_SE", "BIO_BG_ACRE_SE", "BIO_ACRE_SE",
-               "CARB_AG_ACRE_SE","CARB_BG_ACRE_SE","CARB_ACRE_SE","nPlots_TREE",
-               "nPlots_AREA")
+      if (variance){
+        tOut <- tOut %>%
+          select(grpBy, "NETVOL_ACRE","SAWVOL_ACRE","BIO_AG_ACRE","BIO_BG_ACRE",
+                 "BIO_ACRE","CARB_AG_ACRE","CARB_BG_ACRE","CARB_ACRE","NETVOL_ACRE_VAR",
+                 "SAWVOL_ACRE_VAR","BIO_AG_ACRE_VAR", "BIO_BG_ACRE_VAR", "BIO_ACRE_VAR",
+                 "CARB_AG_ACRE_VAR","CARB_BG_ACRE_VAR","CARB_ACRE_VAR","nPlots_TREE",
+                 "nPlots_AREA", 'N')
+      } else {
+        tOut <- tOut %>%
+          select(grpBy, "NETVOL_ACRE","SAWVOL_ACRE","BIO_AG_ACRE","BIO_BG_ACRE",
+                 "BIO_ACRE","CARB_AG_ACRE","CARB_BG_ACRE","CARB_ACRE","NETVOL_ACRE_SE",
+                 "SAWVOL_ACRE_SE","BIO_AG_ACRE_SE", "BIO_BG_ACRE_SE", "BIO_ACRE_SE",
+                 "CARB_AG_ACRE_SE","CARB_BG_ACRE_SE","CARB_ACRE_SE","nPlots_TREE",
+                 "nPlots_AREA")
+      }
+
     }
 
     # Snag the names
@@ -619,7 +857,7 @@ biomass <- function(db,
     suppressMessages({suppressWarnings({
       tOut <- left_join(tOut, polys) %>%
         select(c('YEAR', grpByOrig, tNames, names(polys))) %>%
-        filter(!is.na(polyID))})})
+        filter(!is.na(polyID) & !is.na(nPlots_AREA))})})
 
     ## Makes it horrible to work with as a dataframe
     if (returnSpatial == FALSE) tOut <- select(tOut, -c(geometry))
