@@ -1,21 +1,48 @@
+growMortStarter <- function(x,
+                            db,
+                            grpBy_quo = NULL,
+                            polys = NULL,
+                            returnSpatial = FALSE,
+                            bySpecies = FALSE,
+                            bySizeClass = FALSE,
+                            landType = 'forest',
+                            treeType = 'all',
+                            method = 'TI',
+                            lambda = .5,
+                            stateVar = 'TPA',
+                            treeDomain = NULL,
+                            areaDomain = NULL,
+                            totals = FALSE,
+                            byPlot = FALSE,
+                            nCores = 1,
+                            remote){
 
-#' @export
-growMort <- function(db,
-                     grpBy = NULL,
-                     polys = NULL,
-                     returnSpatial = FALSE,
-                     bySpecies = FALSE,
-                     bySizeClass = FALSE,
-                     landType = 'forest',
-                     treeType = 'all',
-                     method = 'TI',
-                     lambda = .5,
-                     stateVar = 'TPA',
-                     treeDomain = NULL,
-                     areaDomain = NULL,
-                     totals = FALSE,
-                     byPlot = FALSE,
-                     nCores = 1) {
+  reqTables <- c('PLOT', 'COND', 'TREE', 'TREE_GRM_COMPONENT', 'TREE_GRM_MIDPT',
+                 'SUBP_COND_CHNG_MTRX',
+                 'POP_PLOT_STRATUM_ASSGN', 'POP_ESTN_UNIT', 'POP_EVAL',
+                 'POP_STRATUM', 'POP_EVAL_TYP', 'POP_EVAL_GRP')
+
+  if (remote){
+    ## Store the original parameters here
+    params <- db
+
+    ## Read in one state at a time
+    db <- readFIA(dir = db$dir, common = db$common,
+                  tables = reqTables, states = x, ## x is the vector of state names
+                  nCores = nCores)
+
+    ## If a clip was specified, run it now
+    if ('mostRecent' %in% names(params)){
+      db <- clipFIA(db, mostRecent = params$mostRecent,
+                    mask = params$mask, matchEval = params$matchEval,
+                    evalid = params$evalid, designCD = params$designCD,
+                    nCores = nCores)
+    }
+
+  } else {
+    ## Really only want the required tables
+    db <- db[names(db) %in% reqTables]
+  }
 
   ## Need a plotCN
   db$TREE <- db[['TREE']] %>% mutate(TRE_CN = CN)
@@ -23,8 +50,6 @@ growMort <- function(db,
   db$PLOT <- db$PLOT %>% mutate(PLT_CN = CN,
                                 pltID = paste(UNITCD, STATECD, COUNTYCD, PLOT, sep = '_'))
 
-  ##  don't have to change original code
-  grpBy_quo <- enquo(grpBy)
 
   # Probably cheating, but it works
   if (quo_name(grpBy_quo) != 'NULL'){
@@ -49,15 +74,14 @@ growMort <- function(db,
       # Convert to character
       grpBy <- names(d_quo)
     }
+  } else {
+    grpBy <- NULL
   }
 
-  reqTables <- c('PLOT', 'TREE', 'TREE_GRM_COMPONENT', 'COND',
+  reqTables <- c('PLOT', 'TREE', 'TREE_GRM_COMPONENT', 'TREE_GRM_MIDPT', 'COND',
                  'POP_PLOT_STRATUM_ASSGN', 'POP_ESTN_UNIT', 'POP_EVAL',
                  'POP_STRATUM', 'POP_EVAL_TYP', 'POP_EVAL_GRP')
-  ## Some warnings
-  if (class(db) != "FIA.Database"){
-    stop('db must be of class "FIA.Database". Use readFIA() to load your FIA data.')
-  }
+
   if (!is.null(polys) & first(class(polys)) %in% c('sf', 'SpatialPolygons', 'SpatialPolygonsDataFrame') == FALSE){
     stop('polys must be spatial polygons object of class sp or sf. ')
   }
@@ -109,13 +133,13 @@ growMort <- function(db,
 
   ### AREAL SUMMARY PREP
   if(!is.null(polys)) {
-    # Convert polygons to an sf object
-    polys <- polys %>%
-      as('sf')%>%
-      mutate_if(is.factor,
-                as.character)
-    ## A unique ID
-    polys$polyID <- 1:nrow(polys)
+    # # Convert polygons to an sf object
+    # polys <- polys %>%
+    #   as('sf')%>%
+    #   mutate_if(is.factor,
+    #             as.character)
+    # ## A unique ID
+    # polys$polyID <- 1:nrow(polys)
 
     # Add shapefile names to grpBy
     #grpBy = c(names(polys)[str_detect(names(polys), 'geometry') == FALSE], 'polyID', grpBy)
@@ -293,8 +317,8 @@ growMort <- function(db,
 
   # User defined domain indicator for area (ex. specific forest type)
   pcEval <- left_join(db$PLOT, select(db$COND, -c('STATECD', 'UNITCD', 'COUNTYCD', 'INVYR', 'PLOT')), by = 'PLT_CN')
-  areaDomain <- substitute(areaDomain)
-  pcEval$aD <- eval(areaDomain, pcEval) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
+  #areaDomain <- substitute(areaDomain)
+  pcEval$aD <- rlang::eval_tidy(areaDomain, pcEval) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
   if(!is.null(pcEval$aD)) pcEval$aD[is.na(pcEval$aD)] <- 0 # Make NAs 0s. Causes bugs otherwise
   if(is.null(pcEval$aD)) pcEval$aD <- 1 # IF NULL IS GIVEN, THEN ALL VALUES TRUE
   pcEval$aD <- as.numeric(pcEval$aD)
@@ -307,8 +331,8 @@ growMort <- function(db,
   rm(pcEval)
 
   # Same as above for tree (ex. trees > 20 ft tall)
-  treeDomain <- substitute(treeDomain)
-  tD <- eval(treeDomain, db$TREE) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
+  #treeDomain <- substitute(treeDomain)
+  tD <- rlang::eval_tidy(treeDomain, db$TREE) ## LOGICAL, THIS IS THE DOMAIN INDICATOR
   if(!is.null(tD)) tD[is.na(tD)] <- 0 # Make NAs 0s. Causes bugs otherwise
   if(is.null(tD)) tD <- 1 # IF NULL IS GIVEN, THEN ALL VALUES TRUE
   db$TREE$tD <- as.numeric(tD)
@@ -341,6 +365,7 @@ growMort <- function(db,
     left_join(select(db$POP_STRATUM, c('ESTN_UNIT_CN', 'EXPNS', 'P2POINTCNT', 'CN', 'P1POINTCNT', 'ADJ_FACTOR_SUBP', 'ADJ_FACTOR_MICR', "ADJ_FACTOR_MACR")), by = c('ESTN_UNIT_CN')) %>%
     rename(STRATUM_CN = CN) %>%
     left_join(select(db$POP_PLOT_STRATUM_ASSGN, c('STRATUM_CN', 'PLT_CN', 'INVYR', 'STATECD')), by = 'STRATUM_CN') %>%
+    ungroup() %>%
     mutate_if(is.factor,
               as.character)
 
@@ -465,6 +490,8 @@ growMort <- function(db,
       names(tOut) <- str_replace(names(tOut), 'TPA', paste(stateVar, 'ACRE', sep = '_'))
 
     }
+    out <- list(tEst = tOut, grpBy = grpBy, aGrpBy = aGrpBy, grpByOrig = grpByOrig)
+
     ## Population estimation
   } else {
     ## back to dataframes
@@ -551,7 +578,7 @@ growMort <- function(db,
           neu <- wgts %>%
             mutate(l = lambda) %>%
             group_by(ESTN_UNIT_CN) %>%
-            summarize(l = first(lambda),
+            summarize(l = 1-first(lambda),
                       sumwgt = sum(l*(1-l)^(1-rank), na.rm = TRUE))
 
           ## Rejoining and computing wgts
@@ -572,7 +599,7 @@ growMort <- function(db,
           ## Want sum of weighitng functions
           neu <- wgts %>%
             group_by(lambda, ESTN_UNIT_CN) %>%
-            summarize(l = first(lambda),
+            summarize(l = 1-first(lambda),
                       sumwgt = sum(l*(1-l)^(1-rank), na.rm = TRUE))
 
           ## Rejoining and computing wgts
@@ -605,6 +632,139 @@ growMort <- function(db,
 
     }
 
+    out <- list(tEst = tEst, aEst = aEst, grpBy = grpBy, aGrpBy = aGrpBy, grpByOrig = grpByOrig)
+
+  }
+
+  return(out)
+}
+
+
+
+#' @export
+growMort <- function(db,
+                     grpBy = NULL,
+                     polys = NULL,
+                     returnSpatial = FALSE,
+                     bySpecies = FALSE,
+                     bySizeClass = FALSE,
+                     landType = 'forest',
+                     treeType = 'all',
+                     method = 'TI',
+                     lambda = .5,
+                     stateVar = 'TPA',
+                     treeDomain = NULL,
+                     areaDomain = NULL,
+                     totals = FALSE,
+                     variance = FALSE,
+                     byPlot = FALSE,
+                     nCores = 1) {
+
+  ##  don't have to change original code
+  grpBy_quo <- enquo(grpBy)
+  areaDomain <- rlang::enquo(areaDomain)
+  treeDomain <- rlang::enquo(treeDomain)
+
+
+  ### Is DB remote?
+  remote <- ifelse(class(db) == 'Remote.FIA.Database', 1, 0)
+  if (remote){
+
+    iter <- db$states
+
+    ## In memory
+  } else {
+    ## Some warnings
+    if (class(db) != "FIA.Database"){
+      stop('db must be of class "FIA.Database". Use readFIA() to load your FIA data.')
+    }
+
+    ## an iterator for remote
+    iter <- 1
+
+  }
+
+  ### AREAL SUMMARY PREP
+  if(!is.null(polys)) {
+    # Convert polygons to an sf object
+    polys <- polys %>%
+      as('sf')%>%
+      mutate_if(is.factor,
+                as.character)
+    ## A unique ID
+    polys$polyID <- 1:nrow(polys)
+  }
+
+
+
+  ## Run the main portion
+  out <- lapply(X = iter, FUN = growMortStarter, db,
+                grpBy_quo, polys, returnSpatial,
+                bySpecies, bySizeClass,
+                landType, treeType, method,
+                lambda, stateVar, treeDomain, areaDomain,
+                totals, byPlot, nCores, remote)
+  ## Bring the results back
+  out <- unlist(out, recursive = FALSE)
+  aEst <- bind_rows(out[names(out) == 'aEst'])
+  tEst <- bind_rows(out[names(out) == 'tEst'])
+  grpBy <- out[names(out) == 'grpBy'][[1]]
+  aGrpBy <- out[names(out) == 'aGrpBy'][[1]]
+  grpByOrig <- out[names(out) == 'grpByOrig'][[1]]
+
+
+
+  if (byPlot){
+    tOut <- tEst
+
+    ## Population estimates
+  } else {
+
+    ## Check for a most recent subset
+    if (remote){
+      if ('mostRecent' %in% names(db)){
+        mr = db$mostRecent # logical
+      } else {
+        mr = FALSE
+      }
+      ## In-memory
+    } else {
+      if ('mostRecent' %in% names(db)){
+        mr = TRUE
+      } else {
+        mr = FALSE
+      }
+    }
+
+    suppressMessages({suppressWarnings({
+      ## If a clip was specified, handle the reporting years
+      if (mr){
+        ## If a most recent subset, ignore differences in reporting years across states
+        ## instead combine most recent information from each state
+        # ID mr years by group
+        maxyearsT <- tEst %>%
+          select(grpBy) %>%
+          group_by(.dots = grpBy[!c(grpBy %in% 'YEAR')]) %>%
+          summarise(YEAR = max(YEAR, na.rm = TRUE))
+        maxyearsA <- aEst %>%
+          select(aGrpBy) %>%
+          group_by(.dots = aGrpBy[!c(aGrpBy %in% 'YEAR')]) %>%
+          summarise(YEAR = max(YEAR, na.rm = TRUE))
+
+        # Combine estimates
+        aEst <- aEst %>%
+          ungroup() %>%
+          select(-c(YEAR)) %>%
+          left_join(maxyearsA, by = aGrpBy[!c(aGrpBy %in% 'YEAR')])
+        tEst <- tEst %>%
+          ungroup() %>%
+          select(-c(YEAR)) %>%
+          left_join(maxyearsT, by = grpBy[!c(grpBy %in% 'YEAR')])
+
+      }
+    })})
+
+
     ##---------------------  TOTALS and RATIOS
     # Area
     # aTotal <- aEst %>%
@@ -657,12 +817,25 @@ growMort <- function(db,
                RECR_PERC_SE = sqrt(rpVar) / RECR_PERC * 100,
                MORT_PERC_SE = sqrt(mpVar) / MORT_PERC * 100,
                REMV_PERC_SE = sqrt(hpVar) / REMV_PERC * 100,
+               ## Var ratio
+               RECR_TPA_VAR = raVar,
+               MORT_TPA_VAR = maVar,
+               REMV_TPA_VAR = haVar,
+               RECR_PERC_VAR = rpVar,
+               MORT_PERC_VAR = mpVar,
+               REMV_PERC_VAR = hpVar,
                ## SE TOTAL
                AREA_TOTAL_SE = sqrt(aVar) / AREA_TOTAL *100,
                TREE_TOTAL_SE = sqrt(tVar) / TREE_TOTAL *100,
                RECR_TOTAL_SE = sqrt(rVar) / RECR_TOTAL *100,
                MORT_TOTAL_SE = sqrt(mVar) / MORT_TOTAL *100,
                REMV_TOTAL_SE = sqrt(hVar) / REMV_TOTAL *100,
+               ## VAR TOTAL
+               AREA_TOTAL_VAR = aVar,
+               TREE_TOTAL_VAR = tVar,
+               RECR_TOTAL_VAR = rVar,
+               MORT_TOTAL_VAR = mVar,
+               REMV_TOTAL_VAR = hVar,
                ## nPlots
                # Non-zero plots
                nPlots_TREE = plotIn_t,
@@ -674,17 +847,35 @@ growMort <- function(db,
 
     # Make some columns go away
     if (totals) {
-      tOut <- tOut %>%
-        select(grpBy, RECR_TPA, MORT_TPA, REMV_TPA, RECR_PERC, MORT_PERC, REMV_PERC,
-               TREE_TOTAL, RECR_TOTAL, MORT_TOTAL, REMV_TOTAL, AREA_TOTAL,
-               RECR_TPA_SE, MORT_TPA_SE, REMV_TPA_SE, RECR_PERC_SE, MORT_PERC_SE, REMV_PERC_SE,
-               TREE_TOTAL_SE, RECR_TOTAL_SE, MORT_TOTAL_SE, REMV_TOTAL_SE, AREA_TOTAL_SE,
-               nPlots_TREE, nPlots_RECR, nPlots_MORT, nPlots_REMV, nPlots_AREA)
+      if (variance){
+        tOut <- tOut %>%
+          select(grpBy, RECR_TPA, MORT_TPA, REMV_TPA, RECR_PERC, MORT_PERC, REMV_PERC,
+                 TREE_TOTAL, RECR_TOTAL, MORT_TOTAL, REMV_TOTAL, AREA_TOTAL,
+                 RECR_TPA_VAR, MORT_TPA_VAR, REMV_TPA_VAR, RECR_PERC_VAR, MORT_PERC_VAR, REMV_PERC_VAR,
+                 TREE_TOTAL_VAR, RECR_TOTAL_VAR, MORT_TOTAL_VAR, REMV_TOTAL_VAR, AREA_TOTAL_VAR,
+                 nPlots_TREE, nPlots_RECR, nPlots_MORT, nPlots_REMV, nPlots_AREA, N)
+      } else {
+        tOut <- tOut %>%
+          select(grpBy, RECR_TPA, MORT_TPA, REMV_TPA, RECR_PERC, MORT_PERC, REMV_PERC,
+                 TREE_TOTAL, RECR_TOTAL, MORT_TOTAL, REMV_TOTAL, AREA_TOTAL,
+                 RECR_TPA_SE, MORT_TPA_SE, REMV_TPA_SE, RECR_PERC_SE, MORT_PERC_SE, REMV_PERC_SE,
+                 TREE_TOTAL_SE, RECR_TOTAL_SE, MORT_TOTAL_SE, REMV_TOTAL_SE, AREA_TOTAL_SE,
+                 nPlots_TREE, nPlots_RECR, nPlots_MORT, nPlots_REMV, nPlots_AREA)
+      }
+
     } else {
-      tOut <- tOut %>%
-        select(grpBy, RECR_TPA, MORT_TPA, REMV_TPA, RECR_PERC, MORT_PERC, REMV_PERC,
-               RECR_TPA_SE, MORT_TPA_SE, REMV_TPA_SE, RECR_PERC_SE, MORT_PERC_SE, REMV_PERC_SE,
-               nPlots_TREE, nPlots_RECR, nPlots_MORT, nPlots_REMV,nPlots_AREA)
+      if (variance){
+        tOut <- tOut %>%
+          select(grpBy, RECR_TPA, MORT_TPA, REMV_TPA, RECR_PERC, MORT_PERC, REMV_PERC,
+                 RECR_TPA_VAR, MORT_TPA_VAR, REMV_TPA_VAR, RECR_PERC_VAR, MORT_PERC_VAR, REMV_PERC_VAR,
+                 nPlots_TREE, nPlots_RECR, nPlots_MORT, nPlots_REMV,nPlots_AREA, N)
+      } else {
+        tOut <- tOut %>%
+          select(grpBy, RECR_TPA, MORT_TPA, REMV_TPA, RECR_PERC, MORT_PERC, REMV_PERC,
+                 RECR_TPA_SE, MORT_TPA_SE, REMV_TPA_SE, RECR_PERC_SE, MORT_PERC_SE, REMV_PERC_SE,
+                 nPlots_TREE, nPlots_RECR, nPlots_MORT, nPlots_REMV,nPlots_AREA)
+      }
+
     }
 
     # Snag the names
@@ -727,7 +918,7 @@ growMort <- function(db,
     suppressMessages({suppressWarnings({
       tOut <- left_join(tOut, polys, by = 'polyID') %>%
         select(c('YEAR', grpByOrig, tNames, names(polys))) %>%
-        filter(!is.na(polyID))})})
+        filter(!is.na(polyID) & !is.na(nPlots_AREA))})})
 
     ## Makes it horrible to work with as a dataframe
     if (returnSpatial == FALSE) tOut <- select(tOut, -c(geometry))
